/// <reference types="react" />
declare type SizeType = "middle" | "small" | "large";
interface TableInterface {
    columns: ColumnType<{}>[];
    fetchTableFun: (params: any) => Promise<{}>;
    fetchParams?: {
        [key: string]: any;
    };
    hasPagination?: boolean;
    number?: number;
    searchNumber?: number;
    size?: SizeType;
    bordered?: boolean;
    rowKey?: string;
    otherTableProps?: {
        [key: string]: any;
    };
}
interface ResponseDataInterface {
    list: {}[];
    pageNum?: number;
    pageSize?: number;
    total?: number;
    [key: string]: any;
}
export declare type Key = React.Key;
export declare type FixedType = 'left' | 'right' | boolean;
export declare type DefaultRecordType = Record<string, any>;
export declare type TableLayout = 'auto' | 'fixed';
declare type GetComponentProps<DataType> = (data: DataType, index?: number) => React.HTMLAttributes<HTMLElement>;
declare type ColumnsType<RecordType = unknown> = (ColumnGroupType<RecordType> | ColumnType<RecordType>)[];
declare type CellEllipsisType = {
    showTitle?: boolean;
} | boolean;
declare type AlignType = 'left' | 'center' | 'right';
declare type DataIndex = string | number | (string | number)[];
interface CellType<RecordType> {
    key?: Key;
    className?: string;
    style?: React.CSSProperties;
    children?: React.ReactNode;
    column?: ColumnsType<RecordType>[number];
    colSpan?: number;
    rowSpan?: number;
    hasSubColumns?: boolean;
    colStart?: number;
    colEnd?: number;
}
interface ColumnGroupType<RecordType> extends ColumnSharedType<RecordType> {
    children: ColumnsType<RecordType>;
}
interface RenderedCell<RecordType> {
    props?: CellType<RecordType>;
    children?: React.ReactNode;
}
interface ColumnSharedType<RecordType> {
    title?: React.ReactNode;
    key?: Key;
    className?: string;
    fixed?: FixedType;
    onHeaderCell?: GetComponentProps<ColumnsType<RecordType>[number]>;
    ellipsis?: CellEllipsisType;
    align?: AlignType;
}
interface ColumnType<RecordType> extends ColumnSharedType<RecordType> {
    colSpan?: number;
    dataIndex?: DataIndex;
    render?: (value: any, record: RecordType, index: number) => React.ReactNode | RenderedCell<RecordType>;
    shouldCellUpdate?: (record: RecordType, prevRecord: RecordType) => boolean;
    rowSpan?: number;
    width?: number | string;
    onCell?: GetComponentProps<RecordType>;
    onCellClick?: (record: RecordType, e: React.MouseEvent<HTMLElement>) => void;
}
export { TableInterface, ResponseDataInterface, ColumnType, };
